@@ -22,7 +22,7 @@ class Document(CandidatesOrganizationModel, table=True):
     candidate: "Candidate" = Relationship(back_populates="documents")
 
     application_id: Optional[UUID] = Field(foreign_key="application.id", ondelete="SET NULL", index=False, nullable=True)
-    application: "Candidate" = Relationship(back_populates="documents")
+    application: "Application" = Relationship(back_populates="documents")
 
 
 class Candidate(CandidatesOrganizationModel, table=True):
