@@ -232,6 +232,7 @@ class FeedInfo(ResolvableCompanyModel):
     source_type: str
     last_sync_date: Optional[datetime]
     synced_vacancy_count: int
+    sanitize_options: Optional[dict]
     mapping: List[Mapping]
     custom_fields: List[Mapping]
 
@@ -261,6 +262,7 @@ class FeedInfo(ResolvableCompanyModel):
             source_type=model.source_type,
             last_sync_date=model.last_sync_date,
             synced_vacancy_count=model.synced_vacancy_count,
+            sanitize_options=model.sanitize_options,
             mapping=model.mapping,
             custom_fields=model.custom_fields,
         )
